Package: rpivotTable
Title: Build Powerful Pivot Tables and Dynamically Slice & Dice your
        Data
Date: 2026-08-06
Version: 0.4.0
Authors@R: c(
    person("Enzo", "Martoglio", role = c("aut")),
    person("Nicolas", "Kruchten", role = c("ctb", "cph")),
    person("Nagarajan", "Chinnasamy", role = c("ctb", "cph")),
    person("Kenton", "Russell", role = c("ctb")),
    person("Lily", "Clements", role = c("cre"), email = "lily@idems.international")
    )
Maintainer: Lily Clements  <lily@idems.international>
Description: Build powerful pivot tables (aka Pivot Grid, Pivot Chart, Cross-Tab)
    and dynamically slice & dice / drag 'n' drop your data. 'rpivotTable' is a
    wrapper of 'pivottable', a powerful open-source Pivot Table library implemented
    in 'JavaScript' by Nicolas Kruchten. Aligned to 'pivottable' v2.19.0.
Depends: R (>= 3.2.0)
Imports: htmlwidgets (>= 0.5)
Suggests: data.table, devtools, dplyr, htmltools, knitr, rmarkdown,
        testthat, tibble
Enhances: shiny (>= 0.12)
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/smartinsightsfromdata,
        https://github.com/idemsinternational
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-08-24 14:20:17 UTC; lclem
Author: Enzo Martoglio [aut],
  Nicolas Kruchten [ctb, cph],
  Nagarajan Chinnasamy [ctb, cph],
  Kenton Russell [ctb],
  Lily Clements [cre]
Repository: CRAN
Date/Publication: 2026-08-24 18:50:10 UTC
Built: R 4.5.2; ; 2026-08-24 22:40:35 UTC; unix
